clear all
close all

g=9.8;  %Gravity acceleration

%Beam data
wb=0.179; %width
hb=1.120; %heigth
L=17.620; %Span length (m)
rho_b=4.0; %Apparent density of the beam kN/m^3 (tab A.3 EN 1991-1)
fmk=32;  %Characteristic bending resistance (N/mm^2), (5% fractile).
fvk=3.2; %Characteristic shear resistance. NS-EN 1194 (Obsolete norwegian 
         %code, should check a more recent source, but the number is 
         %probably identical.)

ls=4.5; %Load width (m). The beam in question is fairly close to the middle of the roof structure which has a high number of equally sized beams. We will therefore assume that the load will be distributed evenly between this beam and the adjacent ones.
gam0=1.15; %Partial safety factor for glued laminated timber after
           %EN 1995-1-1 tab NA.2.3 (norwegian national annex)
           

kmodA=0.8; %Modification factors for resistance after EN 1995-1-1 tab 3.1. 
kmodB=0.6; %Takes into account load duration and relative moisture levels.
           %Assuming service class 1

RdA=fmk/gam0*kmodA; %Design resistance, bending.
RdB=fmk/gam0*kmodB;

RvdA=fvk*kmodA/gam0; %Design resistance, shear. 
RvdB=fvk*kmodB/gam0; 


%Loads are assessed according to Eurocode (EN 1990 and EN 1991)
%Category 4, regular building, nominal service life: 50 years.

%Reliability class 2


%In this document capital letters signify characteristic load per unit of 
%area (kN/m^2), lower case is characteristic load per unit of length
%(kN/m).

%%Variable actions (Q,q)%%

%Imposed load Ql (maintenance work etc.)
Qi=0.75;  %Chosen from EN 1991 1-1 tab NA.6.10 (Norwegian national annex), 
qi=Qi*ls;
          
%Snow load Qs (Zurich)
Qs=0.9; %As per the swiss standard
qs=Qs*ls;
%Elevation in Zurich is about 400 m.o.h.


%%Permanent actions (G)%%

%Self weigth Gs (Roof)
Gr=0.3; %Guess
gr=Gr*ls;


gb=hb*wb*rho_b; %Self weight of the beam (kN/m).

%Dead load Gf (Filling, green roof)
Gf=0.8;   
gf=Gf*ls; 


%%Load combinations:

%Combination factors for variable loads:
%psi0, basic combination factor. psi1, often occuring. psi2, approximately
%permanent.
psi0_s=0.7; %Snow load
psi0_i=0; %Imposed load

CombA=1.5*(qs+psi0_i*qi)+1.2*(gr+gb+gf); %Combination A, snow is dominant
CombB=1.5*(psi0_s*qs+psi0_i*qi)+1.35*(gr+gb+gf); %Combination B, self weight is dominant

VmaxA=CombA*L/2; %Maximum design shear force (kN)
VmaxB=CombB*L/2;

TaudA=1.5/0.67*VmaxA/hb/wb/10^3 %Design shear stress
TaudB=1.5/0.67*VmaxB/hb/wb/10^3

RdVA=fvk/gam0*kmodA %Design shear resistance
RdVB=fvk/gam0*kmodB

MmaxA=CombA*L^2/8; %Maximum design moment (kNm)
MmaxB=CombB*L^2/8;

SdA=MmaxA/(wb*hb^2/6*10^9)*10^6 %Maximum design stress due to bending (MPa)
SdB=MmaxB/(wb*hb^2/6*10^9)*10^6 

RdA %Design bending resistance (MPa)
RdB































