function [alph]=DoL_damage1_tri(B,C,D,t0,t,Sc,Sc_tri,R0,alph0)

%Foschi & Yao model (1986)

%Damage accumulation for load over time shaped as an isosceles triangle
%Duration is t-t0, max stress is Sc_tri+Sc at time=(t-t0)/2

eta=0.5; %Damage threshold

k=Sc_tri/((t-t0)/2); %Rate of loading

A=(k*(B+1))/(R0*(1-eta)^(B+1));

n_it=1000; %Number of iterations for numerical solution.
alph=alph0; %Initial damage
dt=(t-t0)/n_it; %Time segment

Sct=zeros(n_it,1);

if Sc+Sc_tri>eta*R0 %Skips iteration completely if max load is below the threshold
    if Sc+Sc_tri>R0 %Designates failure if load is above R0
        alph=1.1;
    else

%First half
for n=1:n_it/2
    if alph>1
        break
    end
    Sct(n)=Sc_tri*2*n/n_it+Sc; %Load is increasing up to the half-way point
    if Sct(n)>eta*R0 %No damage accumulation below the threshold
        alph=alph+(A*(Sct(n)/R0-eta)^B+C*(Sct(n)/R0-eta)^D*alph)*dt;
    end
end

for n=n_it/2:n_it
%Second half
    if alph>1
        break
    end
    Sct(n)=Sc_tri*2*(1-n/n_it)+Sc; %Load is decreasing towards zero at the end
    if Sct(n)>eta*R0 %No damage accumulation below the threshold
        alph=alph+(A*(Sct(n)/R0-eta)^B+C*(Sct(n)/R0-eta)^D*alph)*dt;
    end
end
    end
    
end
























