clear all
close all

%In this script the subscript "1" refers to Foschi & Yao's method,
%"2" refers to Gerhards method

%Depentant on special functions:
%DoL_damage1_C -> Foschi & Yao's method for constant load
%DoL_damage2_C -> Gerhards' method for constant load
%DoL_damage1_tri -> Foschi & Yao's method for triangle load
%DoL_damage2_tri -> Gerhards' method for triangle load

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Variable parameters                
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

k=1*365*24;   %Rate of loading (MPa/year)
Gf=0.8;       %Load from filling (kN/m^2). 0.8 for ideal, 2.4 for overload
t_sim=10;     %Time to consider (years)
nb=10^7;      %Number of realizations
hb=1.12;      %Cross-sectional heigth (m), 1.12m for actual, 0.911m for optimized

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Calculating lognormal mean based on known 5% fractile and cov:
my=0; %Standard lognormal mean
sig=1; %Standard lognormal sd.
z005=norminv(0.05,my,sig); %normal variate for 5% fractile

Rk=32; %Characteristic bending resistance (N/mm^2), (5% fractile).
covR=0.25; %Coefficient of variation for bending resistance
sig=sqrt(log(covR^2+1)); %lognormal sd, is independent of mean

myR0=log(Rk)-sig*z005; %Logarithmic mean for R0
mR0=exp(myR0)*sqrt(covR^2+1); %Arithmetic mean for R0

%Beam data
wb=0.179; %width (m)
%hb=1.12; %heigth (m), defined at the top
L=17.620; %Span length (m)
rho_b=4.0; %Apparent density of the beam kN/m^3 (tab A.3 EN 1991-1)
W=hb^2*wb/6; %Section modulus (m^3)
sdR0=mR0*covR; %Standard deviation

myR=log(mR0^2/sqrt(sdR0^2+mR0^2)); %Logarithmic mean
sigR=sqrt(log(1+sdR0^2/mR0^2));   %Logarithmic sd

ls=4.5; %Load width (m).

cf=L^2/(W*8*1000); %Converts line loads to max. stress in the beam.
cf2=W/ls*8/L^2*1000; %Conversion factor, max. MPa in the beam to kN/m^2
                     

%%Variable action%%
 
%Snow load Qs (Zurich)
gam=0.5772; %Euler Mascheroni constant
SFD=15.2; %Snowfall days (yearly)
SCD=33.2; %Snow cover days (yearly)
Qsk=0.9; % 98% fractile for yearly ground snow load. Determined by the Swiss standard

cvs=0.21; %Coefficient of variation (yearly)
lam_s=SFD/1.5; %Expected number of yearly snow packages. Assumption is based on SFD.
mean_s=1/lam_s; %Mean for exponential dist. time between packages

%One year parameters
p1=0.98; %p. for no exceedance of Qsk over 1 year. 
zp1=-log(-log(p1)); %z value for p1
m1=Qsk/(1+cvs*sqrt(6)/pi*(-gam+zp1)); %1 year mean
sd=m1*cvs; %Standard deviation, constant
beta=sqrt(6)*sd/pi; %Beta, Gumbel value, constant
my1=m1-beta*gam; %One year mode

%Determining parameters for a single snow package:  
p0=0.98^(1/lam_s); %p. for no exceedance of Qsk in a single package
zp0=-log(-log(p0)); %z value for p1 
my0=Qsk-zp0*beta; %Mode for one package
m0=my0+beta*gam; %Mean
mSn=m0*cf2; %Mean stress on the beam, snow (MPa)

%Duration of snow pack is Pm*Xt
%Pm is the magnitude of a snow pack (kN/m^2)
%Xt is an exponentially distributed relation between tpack and Pm
mt=SCD/lam_s; %Mean pack duration (days)
mXt=mt/m0; %Mean for Xt (days/MPa)


%Roof shape factor: Determines the relation between load on the ground, and the roof.
msf=1; %mean
cvsf=0.35; %coefficient of variation
sdsf=msf*cvsf; 
betasf=sqrt(6)/pi*sdsf; %Beta
mysf=msf-betasf*gam; %mode


%%Permanent actions (G)%%

%Self weigth Gs (Roof)
Gr=0.3;                          %Assumed
gr=Gr*ls;                        %Beam load
cov_gr=0.1;                      %Assumed coefficient of variation
sdrf=cov_gr*gr;                  %Standard deviation
siggr=sqrt(log(1+sdrf^2/gr^2));  %Logarithmic sd
grl=log(gr^2/sqrt(sdrf^2+gr^2)); %Logarithmic mean

%Self weight of the beam
gb=hb*wb*rho_b; %Self weight of the beam (kN/m).
cov_gb=0.1; %PMC part II, tab 2.1.1, all regular species of timber.
sdb=cov_gb*gb;
sigb=sqrt(log(1+sdb^2/gb^2));   %Logarithmic sd
gbl=log(gb^2/sqrt(sdb^2+gb^2)); %Logarithmic mean

%Dead load Gf, filling, green roof
%Gf=Gf; Mean load for the filling. Defined at the top.
                                
gf=Gf*ls;                       %Beam load
cov_gf=0.1;                     %Assumed cov.
sdf=cov_gf*gf;                  %Standard deviation
sigf=sqrt(log(1+sdf^2/gf^2));   %Logarithmic sd
gfl=log(gf^2/sqrt(sdf^2+gf^2)); %Logarithmic mean
          
%Means for permanent stresses:
m_gr=grl*L^2/8/W/1000; %Logarithmic mean stress roof
m_gb=gbl*L^2/8/W/1000; %Logarithmic mean stress beam
m_gf=gfl*L^2/8/W/1000; %Logarithmic mean stress filling

%Log. sd for permanent stresses
siggrs=siggr*cf; %Roof
sigbs=sigb*cf; %Beam
sigfs=sigf*cf; %Filling

%DoL parameters

alph0=0;%Initial damage
t0=0; %Starting time, (years)
%k=k; %Rate of loading up to Sc, (MPa/hour). Defined at the top

%1: Foschi & Yao's model

eta=0.5; %Damage threshold. No damage is accumulated at loads below eta*R0.

%Model parameters B, C and D: 
mB=30.03; %Mean
sdB=0.92; %SD
B=norminv(rand,mB,sdB);

mC=17.05; %Mean
sdC=12.30; %SD
C=norminv(rand,mC,sdC)*365*24; %Unit is converted from 1/hour to 1/year (Kohler 2011)

mD=5.69; %Mean
sdD=0.45; %SD
D=norminv(rand,mD,sdD);

%2: Gerhards' model

%Model parameter b:
mb=51.41;
sdb=0.01;
b=norminv(rand,mb,sdb)+log(365*24); %unit is converted from ln(h^-1) to ln(y^-1) (Kohler 2011)


%%Determining snow packages%%
%t_sim=t_sim; %Time to consider (years). Defined at the top 
n_int=1000; %Number of intervals between packages. Size is irrelevant as long as it is large enough to span more than 50 years.
t1=zeros(n_int,1); %Time between snow packages (years)
Pm=zeros(n_int,1);
Xt=zeros(n_int,1);


%%Monte Carlo simulation%%
%nb=nb; %Number of realizations. Defined at the top
c1=0; %Counter for failures
c2=0;

R0v=zeros(nb,1); %Vector for short term strengths
alph1_vector=zeros(nb,1); %Vectors for alpha-values
alph2_vector=zeros(nb,1);
ML=zeros(nb,1); %Vector for maximum load



tic
for n2=1:nb
t=0; %Counter for time 
%Generating snow packages:
sf=(mysf-betasf*log(-log(rand))); %Roof shape factor
n_sim=0; %Counter for snowfall
for n=1:n_int
t1(n)=-log(1-rand)*mean_s; %Time between starting time of the packages (years), t1(1) is then the time before the first package.
Pm(n)=my0-beta*log(-log(rand))*sf; %Max magnitude per package (kN/m^2)
Xt(n)=-log(1-rand)*mXt/365; %Duration factor (y/kN*m^2)
t=t+t1(n); %Total time passed (y)
n_sim=n_sim+1;
if t>=t_sim
    break %Stops iteration after the relevant amount of time have passed n_sim is now the number of packages in the relevant period. Xt(n).*Pm(n) is the duration of snow package n.
end

end


R0=logninv(rand,myR,sigR); %Short term resistance
R0v(n2)=R0; %Storing R0
Sg=logninv(rand,m_gr,siggrs)+logninv(rand,m_gb,sigbs)+logninv(rand,m_gf,sigfs);            
%Permanent stress
ML(n2)=max(Pm)/cf2+Sg;

t0=0; %Starting time

%Calculating damage from DoL-effect:
alph0=0;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%1: Foschi & Yao
alph1=alph0; %Initial damage
check1=0; %Checks for failure
t2=t0; %Starting time
for n=1:n_sim
alph1=DoL_damage1_C(B,C,D,t2,t1(n),Sg,R0,alph1,k); %Damage accumulation 
                                                   %between snow packages
                                                 
t2=t1(n)+Pm(n).*Xt(n); %End time for this cycle/starting time for the next.

alph1=DoL_damage1_tri(B,C,D,t1(n),t2,Sg,Pm(n)/cf2,R0,alph1);
%Damage accumulation during snow package
if alph1>=1
    break %Ends calculations if failure happens.
end
end

alph1_vector(n2)=alph1; %stores damage value
if alph1>=1
    c1=c1+1; %Counts failure
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%2: Gerhards
alph2=alph0; %Initial damage
check2=0; %Checks for failure
t2=t0; %Starting time
for n=1:n_sim
alph2=DoL_damage2_C(b,t2,t1(n),Sg,R0,alph2,k); %Damage accumulation
                                               %between snow packages
                                               
t2=t1(n)+Pm(n).*Xt(n); %End time for this cycle/starting time for the next.

alph2=DoL_damage2_tri(b,t1(n),t2,Sg,Pm(n)/cf2,R0,alph2);
%Damage accumulation during snow package

if alph2>1
    break %Ends calculations if failure happens.
end
end

alph2_vector(n2)=alph2;
if alph2>=1
    c2=c2+1; %Counts failure
end


end

toc


pfailure1=c1/nb %p. failure for a beam using this method
beta1=-norminv(pfailure1,0,1); %Beta, z-value for pfailure (standard normal distribution)
pfailure2=c2/nb %p. failure for a beam using this method
beta2=-norminv(pfailure2,0,1); %Beta, z-value for pfailure (standard normal distribution)


save roof_sim_latest.mat %Safety copy of latest results
% save 10year_overload.mat


c19=0; %Counter for survivors
c29=0; %Counter for survivors

%Sorting surviving beams from the broken ones.
for n=1:nb
    if alph1_vector(n)<1
        c19=c19+1; %Counts number of survivors for Foschi & Yao
        alph1_vectorb(c19,1)=alph1_vector(n); %Stores surviving damage values
        R0v1(c19,1)=R0v(n); %Stores surviving bending strengths
    end
    
    if alph2_vector(n)<1
        c29=c29+1; %Counts number of survivors for Gerhards
        alph2_vectorb(c29,1)=alph2_vector(n); %Stores surviving damage values
        R0v2(c29,1)=R0v(n); %Stores surviving bending strengths
    end
end

if c1==0 %Prevents error if no failures
    alph1_vectorb=alph1_vector*0;
end
if c2==0 %prevents error if no failures
    alph2_vectorb=alph2_vector*0;
end

ep=60; %Endpoint for plots
r=0:0.01:ep; %Field variable for resistance

%Strength reductions
red1=eta+(1-eta)*(1-alph1_vectorb).^(1/(1+B));
red2=1/b*log(1+(1-alph2_vectorb)*(exp(b)-1));

%Residual strengths:
R0r1=R0v1.*red1; %Vectors for residual strength
R0r2=R0v2.*red2; 

mR0r1=mean(R0r1); %Means for residual strengths
mR0r2=mean(R0r2);

sdR0r1=std(R0r1); %Sd for resiudal strengths
sdR0r2=std(R0r2);

myR1=log(mR0r1^2/sqrt(sdR0r1^2+mR0r1^2)); %Reduced logarithmic mean
myR2=log(mR0r2^2/sqrt(sdR0r2^2+mR0r2^2)); %Reduced logarithmic mean

sigR1=sqrt(log(1+sdR0r1^2/mR0r1^2)); %Reduced logarithmic sd
sigR2=sqrt(log(1+sdR0r2^2/mR0r2^2)); %Reduced logarithmic sd


%Updated cdfs for reduced resistances
cdfR0r1=(logncdf(r,myR1,sigR1)-pfailure1)/(1-pfailure1); 
cdfR0r2=(logncdf(r,myR2,sigR2)-pfailure2)/(1-pfailure2);

% cdfR0=logncdf(r,myR,sigR); %Cdf for initial resistance
% cdfR01=(cdfR0-pfailure1)/(1-pfailure1); %Unreduced updated resistances
% cdfR02=(cdfR0-pfailure2)/(1-pfailure2);


%Pdfs
r1=logninv(pfailure1,myR,sigR):0.01:ep; %Variables for pdfs, starting point
r2=logninv(pfailure2,myR,sigR):0.01:ep; %is the zero point for each plot.

lr=length(r);   %Lengths of field variables
lr1=length(r1);
lr2=length(r2);

cdf1=cdfR0r1(lr-lr1+1:lr); %Cdfs cut at the zero point
cdf2=cdfR0r2(lr-lr2+1:lr);
PDF1=gradient(cdf1)/0.01; %Pdfs
PDF2=gradient(cdf2)/0.01;

%Variables for vertical lines
r3=[logninv(pfailure1,myR,sigR)-0.01,logninv(pfailure1,myR,sigR)];
r4=[logninv(pfailure2,myR,sigR)-0.01,logninv(pfailure2,myR,sigR)];

%Draws vertical lines to the starting point of the pdfs
vl1=[0,PDF1(1,1)]; 
vl2=[0,PDF2(1,1)];

%Plots all three pdfs
figure
plot(sort(R0v),'r')
hold on
plot(sort(R0v1),'g')
plot(sort(R0v2),'b')


time=toc; %Saves time to completion











